*****************************
arithmeticcurve API-reference
*****************************

.. autosummary::
   :toctree:

    examplecurves.Static.create
    examplecurves.NonLinear0
    examplecurves.HorizontalLinear0